# More advanced plotting techniques in PyARPES

In addition to the ones discussed previously, certain types of more complicated plots 
frequently encountered in ARPES analyses are included out of the box.

As a general workflow rule of thumb, you can either use these techniques as a starting point,
modifying the axes and objects returned before saving your figure, or copy the code or 
technique for a one off figure that requires more customization.

If you encounter a use case you think should be supported, get in contact with Conrad and
he can add the functionality, or become a [contributor](/contributing).

## PyARPES plotting routines and techniques 

* [Stacked EDC/line plots](/stack-plots)
* [Fermi surfaces](/fermi-surfaces)
* [3D cut plots](/3d-cut-plots)
* [Dispersion plots](/dispersion-plots)
* [Spin-ARPES plots](/spin-arpes)
* [Ultrafast-ARPES plots](/tr-arpes)

Finally, there is a discussion on: 

* [Plot annotations](/annotations)
* [Labeling and axis utilities](/plotting-utilities)